@@ -14,6 +14,7 @@ class MobileISPInfo:
         icc_donor="",
         previous_contract_type="no",
         delivery_address=None,
+        invoice_address=None,
     ):
         self.phone_number = phone_number
         self.type = type
@@ -26,3 +27,5 @@ class MobileISPInfo:
         self.previous_contract_type = previous_contract_type
         if delivery_address:
             self.delivery_address = Address(**delivery_address)
+        if invoice_address:
+            self.invoice_address = Address(**invoice_address)
